import { attachShadow, h, proxyCustomElement } from '@stencil/core/internal/client';
export { setAssetPath, setPlatformOptions } from '@stencil/core/internal/client';

function format(first, middle, last) {
  return (first || '') + (middle ? ` ${middle}` : '') + (last ? ` ${last}` : '');
}

const barProgressCss = ":host{display:block}.cont{margin:2px 0;background:rgba(0, 200, 0, .15);border-radius:50px}.cont .loader{position:relative;box-sizing:border-box;background:rgba(0, 200, 0, .7);border-radius:50px;transition:width 1.5s linear}.cont .loader:before{content:\"\";position:absolute;top:0;left:0;height:100%;border-radius:50px;width:100%;background:linear-gradient(to  right, rgba(0, 200, 0, .3), rgba(0, 100, 0, .8));animation:purge 4s infinite ease-out}@keyframes purge{0%{opacity:0;width:0%}50%{opacity:.5}100%{opacity:0;width:100%}}";

const MyComponent$4 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
    /**
     * The first name
     */
    this.progress = "0";
    this.progressSize = "150";
    this.progressColor = "#2ecc71";
  }
  getProgress() {
    return format(this.progress, '', '');
  }
  render() {
    return h("div", { class: "cont", style: {
        height: `${this.progressSize}px`,
        width: `100%`,
      } }, h("div", { class: "loader", style: {
        height: `${this.progressSize}px`,
        width: `${this.getProgress()}%`,
      } }));
  }
  static get style() { return barProgressCss; }
};

const circleProgressCss = ":host{display:block}";

const MyComponent$3 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
    /**
     * The first name
     */
    //@Prop() first: string;
    this.progress = "0";
    this.progressSize = "150";
    this.progressColor = "#2ecc71";
    this.backgroundColor = "#000000";
  }
  getProgress() {
    return format(this.progress, '', '');
  }
  render() {
    return h("div", { style: {
        width: `${this.progressSize}px`,
        height: `${this.progressSize}px`,
        display: `flex`,
        alignItems: `center`,
        justifyContent: `center`,
        background: `conic-gradient(${this.progressColor} ${this.getProgress()}%, 0, #ecf0f1 ${(100 - parseInt(this.getProgress())).toString()}%)`,
        borderRadius: `50%`
      } }, h("div", { style: {
        display: `flex`,
        alignItems: `center`,
        justifyContent: `center`,
        backgroundColor: `${this.backgroundColor}`,
        height: `60%`,
        width: `60%`,
        borderRadius: `50%`,
        boxShadow: `0px 0px 7px 0px rgba(0, 0, 0, 0.1)`
      } }));
  }
  static get style() { return circleProgressCss; }
};

const ionStatusCss = ":host{display:block}";

const MyComponent$2 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
    /**
     * The first name
     */
    this.statusColor = "#2ecc71";
    this.statusSize = "100";
  }
  hexToRgbA(hex) {
    var c;
    if (/^#([A-Fa-f0-9]{3}){1,2}$/.test(hex)) {
      c = hex.substring(1).split('');
      if (c.length == 3) {
        c = [c[0], c[0], c[1], c[1], c[2], c[2]];
      }
      c = '0x' + c.join('');
      return 'rgba(' + [(c >> 16) & 255, (c >> 8) & 255, c & 255].join(',') + ',0.25)';
    }
    throw new Error('Bad Hex');
  }
  render() {
    return h("div", { style: {
        width: `${this.statusSize}px`,
        height: `${this.statusSize}px`,
        display: `flex`,
        alignItems: `center`,
        justifyContent: `center`,
        background: `${this.hexToRgbA(this.statusColor)}`,
        borderRadius: `50%`,
      } }, h("div", { style: {
        display: `flex`,
        alignItems: `center`,
        justifyContent: `center`,
        background: `${this.statusColor}`,
        height: `60%`,
        width: `60%`,
        borderRadius: `50%`,
        boxShadow: `0px 0px 7px 0px rgba(0, 0, 0, 0.1)`
      } }));
  }
  static get style() { return ionStatusCss; }
};

const myComponentCss = ":host{display:block}";

const MyComponent$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
  }
  render() {
    return h("div", null, this.first);
  }
  static get style() { return myComponentCss; }
};

const BarProgress = /*@__PURE__*/proxyCustomElement(MyComponent$4, [1,"bar-progress",{"progress":[1],"progressSize":[1,"progress-size"],"progressColor":[1,"progress-color"]}]);
const CircleProgress = /*@__PURE__*/proxyCustomElement(MyComponent$3, [1,"circle-progress",{"progress":[1],"progressSize":[1,"progress-size"],"progressColor":[1,"progress-color"],"backgroundColor":[1,"background-color"]}]);
const IonStatus = /*@__PURE__*/proxyCustomElement(MyComponent$2, [1,"ion-status",{"statusColor":[1,"status-color"],"statusSize":[1,"status-size"]}]);
const MyComponent = /*@__PURE__*/proxyCustomElement(MyComponent$1, [1,"my-component",{"first":[1]}]);
const defineCustomElements = (opts) => {
  if (typeof customElements !== 'undefined') {
    [
      BarProgress,
  CircleProgress,
  IonStatus,
  MyComponent
    ].forEach(cmp => {
      if (!customElements.get(cmp.is)) {
        customElements.define(cmp.is, cmp, opts);
      }
    });
  }
};

export { BarProgress, CircleProgress, IonStatus, MyComponent, defineCustomElements };
